==> virtual-additions-4.0.0%2B1.21.9-sources.jar: com/github/suninvr/virtualadditions/registry/VAEntityType.java <==
package com.github.suninvr.virtualadditions.registry;

import com.github.suninvr.virtualadditions.VirtualAdditions;
import com.github.suninvr.virtualadditions.entity.*;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1311;
import net.minecraft.class_1317;
import net.minecraft.class_1588;
import net.minecraft.class_1690;
import net.minecraft.class_1792;
import net.minecraft.class_2378;
import net.minecraft.class_2902;
import net.minecraft.class_5132;
import net.minecraft.class_5321;
import net.minecraft.class_7264;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.entity.*;
import java.util.Map;
import java.util.function.Supplier;

import static com.github.suninvr.virtualadditions.VirtualAdditions.idOf;

public class VAEntityType {

    public static final class_1299<ClimbingRopeEntity> CLIMBING_ROPE;
    public static final class_1299<SteelBombEntity> STEEL_BOMB;
    public static final class_1299<TomatoEntity> TOMATO;
    public static final class_1299<AcidSpitEntity> ACID_SPIT;
    public static final class_1299<SpectralBoltEntity> SPECTRAL_BOLT;
    public static final class_1299<LumwaspEntity> LUMWASP;
    public static final class_1299<SalineEntity> SALINE;
    public static final class_1299<SpectreEntity> SPECTRE;
    public static final class_1299<PlayerProjectionEntity> PLAYER_PROJECTION;
    public static final class_1299<class_1690> SOULBLOOM_BOAT;
    public static final class_1299<class_7264> SOULBLOOM_CHEST_BOAT;
    public static final class_1299<LightningBottleEntity> LIGHTNING_BOTTLE;

    public static final Map<class_1299<? extends class_1309>, class_5132> ENTITY_ATTRIBUTES = new java.util.HashMap<>();

    static {
        CLIMBING_ROPE = class_2378.method_10230(class_7923.field_41177, VirtualAdditions.idOf("climbing_rope"), class_1299.class_1300.<ClimbingRopeEntity>method_5903(ClimbingRopeEntity::new, class_1311.field_17715)
                .method_17687(0.25F, 0.25F)
                .method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("climbing_rope"))));

        STEEL_BOMB = class_2378.method_10230(class_7923.field_41177, idOf("steel_bomb"), class_1299.class_1300.<SteelBombEntity>method_5903(SteelBombEntity::new, class_1311.field_17715)
                .method_17687(0.25F, 0.25F)
                .method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("steel_bomb"))));

        TOMATO = class_2378.method_10230(class_7923.field_41177, idOf("tomato"), class_1299.class_1300.<TomatoEntity>method_5903(TomatoEntity::new, class_1311.field_17715)
                .method_17687(0.25F, 0.25F)
                .method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("tomato"))));

        ACID_SPIT = class_2378.method_10230(class_7923.field_41177, idOf("acid_spit"), class_1299.class_1300.<AcidSpitEntity>method_5903(AcidSpitEntity::new, class_1311.field_17715)
                .method_17687(0.25F, 0.25F)
                .method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("acid_spit"))));


        SPECTRAL_BOLT = class_2378.method_10230(class_7923.field_41177, idOf("spectral_bolt"), class_1299.class_1300.<SpectralBoltEntity>method_5903(SpectralBoltEntity::new, class_1311.field_17715)
                .method_17687(0.25F, 0.25F)
                .method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("spectral_bolt"))));

        LUMWASP = class_2378.method_10230(class_7923.field_41177, idOf("lumwasp"), class_1299.class_1300.method_5903(LumwaspEntity::new, class_1311.field_6302)
                .method_17687(1.5F, 0.75F)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("lumwasp"))));

        SALINE = class_2378.method_10230(class_7923.field_41177, idOf("saline"), class_1299.class_1300.method_5903(SalineEntity::new, class_1311.field_6302)
                .method_17687(0.6F, 1.95F).method_27299(8)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("saline"))));

        SPECTRE = class_2378.method_10230(class_7923.field_41177, idOf("spectre"), class_1299.class_1300.method_5903(SpectreEntity::new, class_1311.field_6302)
                .method_17687(0.5F, 0.5F).method_55687(0.25F).method_19947()
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("spectre"))));

        PLAYER_PROJECTION = class_2378.method_10230(class_7923.field_41177, idOf("player_projection"), class_1299.class_1300.method_5903(PlayerProjectionEntity::new, class_1311.field_17715)
                .method_17687(0.5F, 0.5F).method_55687(0.25F).method_63006().method_5904().method_5901()
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("spectre"))));

        LIGHTNING_BOTTLE = class_2378.method_10230(class_7923.field_41177, idOf("lightning_bottle"), class_1299.class_1300.<LightningBottleEntity>method_5903(LightningBottleEntity::new, class_1311.field_17715)
                .method_63006().method_17687(0.25F, 0.25F).method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, idOf("lightning_bottle"))));

        SOULBLOOM_BOAT = class_2378.method_10230(class_7923.field_41177, idOf("soulbloom_boat"), class_1299.class_1300.method_5903(getBoatFactory(() -> VAItems.SOULBLOOM_BOAT), class_1311.field_17715)
                .method_63006().method_17687(1.375F, 0.5625F).method_55687(0.5625F).method_27299(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, idOf("soulbloom_boat"))));

        SOULBLOOM_CHEST_BOAT = class_2378.method_10230(class_7923.field_41177, idOf("soulbloom_chest_boat"), class_1299.class_1300.method_5903(getChestBoatFactory(() -> VAItems.SOULBLOOM_CHEST_BOAT), class_1311.field_17715)
                .method_63006().method_17687(1.375F, 0.5625F).method_55687(0.5625F).method_27299(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, idOf("soulbloom_chest_boat"))));

        ENTITY_ATTRIBUTES.put(LUMWASP, LumwaspEntity.createLumwaspAttributes());
        ENTITY_ATTRIBUTES.put(SALINE, SalineEntity.createSalineAttributes());
        ENTITY_ATTRIBUTES.put(SPECTRE, SpectreEntity.createSpectreAttributes());
        ENTITY_ATTRIBUTES.put(PLAYER_PROJECTION, SpectreEntity.createSpectreAttributes());
    }

    public static void init(){
        class_1317.method_20637(SALINE, class_1317.method_6159(SALINE), class_2902.class_2903.field_13197, class_1588::method_20680);
        class_1317.method_20637(LUMWASP, class_1317.method_6159(LUMWASP), class_2902.class_2903.field_13197, LumwaspEntity::method_20680);
        class_1317.method_20637(SPECTRE, class_1317.method_6159(SPECTRE), class_2902.class_2903.field_13197, SpectreEntity::method_20680);
    }


    private static class_1299.class_4049<class_1690> getBoatFactory(Supplier<class_1792> itemSupplier) {
        return (type, world) -> new class_1690(type, world, itemSupplier);
    }

    private static class_1299.class_4049<class_7264> getChestBoatFactory(Supplier<class_1792> itemSupplier) {
        return (type, world) -> new class_7264(type, world, itemSupplier);
    }
}

==> virtual-additions-4.0.1%2B1.21.10-sources.jar: com/github/suninvr/virtualadditions/registry/VAEntityType.java <==
package com.github.suninvr.virtualadditions.registry;

import com.github.suninvr.virtualadditions.VirtualAdditions;
import com.github.suninvr.virtualadditions.entity.*;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1311;
import net.minecraft.class_1317;
import net.minecraft.class_1588;
import net.minecraft.class_1690;
import net.minecraft.class_1792;
import net.minecraft.class_2378;
import net.minecraft.class_2902;
import net.minecraft.class_5132;
import net.minecraft.class_5321;
import net.minecraft.class_7264;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.entity.*;
import java.util.Map;
import java.util.function.Supplier;

import static com.github.suninvr.virtualadditions.VirtualAdditions.idOf;

public class VAEntityType {

    public static final class_1299<ClimbingRopeEntity> CLIMBING_ROPE;
    public static final class_1299<SteelBombEntity> STEEL_BOMB;
    public static final class_1299<TomatoEntity> TOMATO;
    public static final class_1299<AcidSpitEntity> ACID_SPIT;
    public static final class_1299<SpectralBoltEntity> SPECTRAL_BOLT;
    public static final class_1299<LumwaspEntity> LUMWASP;
    public static final class_1299<SalineEntity> SALINE;
    public static final class_1299<SpectreEntity> SPECTRE;
    public static final class_1299<PlayerProjectionEntity> PLAYER_PROJECTION;
    public static final class_1299<class_1690> SOULBLOOM_BOAT;
    public static final class_1299<class_7264> SOULBLOOM_CHEST_BOAT;
    public static final class_1299<LightningBottleEntity> LIGHTNING_BOTTLE;

    public static final Map<class_1299<? extends class_1309>, class_5132> ENTITY_ATTRIBUTES = new java.util.HashMap<>();

    static {
        CLIMBING_ROPE = class_2378.method_10230(class_7923.field_41177, VirtualAdditions.idOf("climbing_rope"), class_1299.class_1300.<ClimbingRopeEntity>method_5903(ClimbingRopeEntity::new, class_1311.field_17715)
                .method_17687(0.25F, 0.25F)
                .method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("climbing_rope"))));

        STEEL_BOMB = class_2378.method_10230(class_7923.field_41177, idOf("steel_bomb"), class_1299.class_1300.<SteelBombEntity>method_5903(SteelBombEntity::new, class_1311.field_17715)
                .method_17687(0.25F, 0.25F)
                .method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("steel_bomb"))));

        TOMATO = class_2378.method_10230(class_7923.field_41177, idOf("tomato"), class_1299.class_1300.<TomatoEntity>method_5903(TomatoEntity::new, class_1311.field_17715)
                .method_17687(0.25F, 0.25F)
                .method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("tomato"))));

        ACID_SPIT = class_2378.method_10230(class_7923.field_41177, idOf("acid_spit"), class_1299.class_1300.<AcidSpitEntity>method_5903(AcidSpitEntity::new, class_1311.field_17715)
                .method_17687(0.25F, 0.25F)
                .method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("acid_spit"))));


        SPECTRAL_BOLT = class_2378.method_10230(class_7923.field_41177, idOf("spectral_bolt"), class_1299.class_1300.<SpectralBoltEntity>method_5903(SpectralBoltEntity::new, class_1311.field_17715)
                .method_17687(0.25F, 0.25F)
                .method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("spectral_bolt"))));

        LUMWASP = class_2378.method_10230(class_7923.field_41177, idOf("lumwasp"), class_1299.class_1300.method_5903(LumwaspEntity::new, class_1311.field_6302)
                .method_17687(1.5F, 0.75F)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("lumwasp"))));

        SALINE = class_2378.method_10230(class_7923.field_41177, idOf("saline"), class_1299.class_1300.method_5903(SalineEntity::new, class_1311.field_6302)
                .method_17687(0.6F, 1.95F).method_27299(8)
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("saline"))));

        SPECTRE = class_2378.method_10230(class_7923.field_41177, idOf("spectre"), class_1299.class_1300.method_5903(SpectreEntity::new, class_1311.field_6302)
                .method_17687(0.5F, 0.5F).method_55687(0.25F).method_19947()
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("spectre"))));

        PLAYER_PROJECTION = class_2378.method_10230(class_7923.field_41177, idOf("player_projection"), class_1299.class_1300.method_5903(PlayerProjectionEntity::new, class_1311.field_17715)
                .method_17687(0.5F, 0.5F).method_55687(0.25F).method_63006().method_5904().method_5901()
                .method_5905(class_5321.method_29179(class_7924.field_41266, VirtualAdditions.idOf("spectre"))));

        LIGHTNING_BOTTLE = class_2378.method_10230(class_7923.field_41177, idOf("lightning_bottle"), class_1299.class_1300.<LightningBottleEntity>method_5903(LightningBottleEntity::new, class_1311.field_17715)
                .method_63006().method_17687(0.25F, 0.25F).method_27299(4).method_27300(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, idOf("lightning_bottle"))));

        SOULBLOOM_BOAT = class_2378.method_10230(class_7923.field_41177, idOf("soulbloom_boat"), class_1299.class_1300.method_5903(getBoatFactory(() -> VAItems.SOULBLOOM_BOAT), class_1311.field_17715)
                .method_63006().method_17687(1.375F, 0.5625F).method_55687(0.5625F).method_27299(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, idOf("soulbloom_boat"))));

        SOULBLOOM_CHEST_BOAT = class_2378.method_10230(class_7923.field_41177, idOf("soulbloom_chest_boat"), class_1299.class_1300.method_5903(getChestBoatFactory(() -> VAItems.SOULBLOOM_CHEST_BOAT), class_1311.field_17715)
                .method_63006().method_17687(1.375F, 0.5625F).method_55687(0.5625F).method_27299(10)
                .method_5905(class_5321.method_29179(class_7924.field_41266, idOf("soulbloom_chest_boat"))));

        ENTITY_ATTRIBUTES.put(LUMWASP, LumwaspEntity.createLumwaspAttributes());
        ENTITY_ATTRIBUTES.put(SALINE, SalineEntity.createSalineAttributes());
        ENTITY_ATTRIBUTES.put(SPECTRE, SpectreEntity.createSpectreAttributes());
        ENTITY_ATTRIBUTES.put(PLAYER_PROJECTION, PlayerProjectionEntity.createAttributes());
    }

    public static void init(){
        class_1317.method_20637(SALINE, class_1317.method_6159(SALINE), class_2902.class_2903.field_13197, class_1588::method_20680);
        class_1317.method_20637(LUMWASP, class_1317.method_6159(LUMWASP), class_2902.class_2903.field_13197, LumwaspEntity::method_20680);
        class_1317.method_20637(SPECTRE, class_1317.method_6159(SPECTRE), class_2902.class_2903.field_13197, SpectreEntity::method_20680);
    }


    private static class_1299.class_4049<class_1690> getBoatFactory(Supplier<class_1792> itemSupplier) {
        return (type, world) -> new class_1690(type, world, itemSupplier);
    }

    private static class_1299.class_4049<class_7264> getChestBoatFactory(Supplier<class_1792> itemSupplier) {
        return (type, world) -> new class_7264(type, world, itemSupplier);
    }
}
